#include <iostream>
#include <string>
#include <gtk/gtk.h>

void setup_speech();
void teardown_speech();
void SPEAK_DAMN_YOU(const gchar * speech);
void repeat_speech();

